# VeloCycle

Manifold-constrained variational inference for RNA velocity of the cell cycle. This is the repository for the VeloCycle framework. Installation instructions and tutorials can be found below.

## Getting started

Please refer to the installation instructions below as well as the [tutorials](https://github.com/lamanno-epfl/velocycle/tree/main/tutorials) contained in this repo.

## Installation

You need to have Python 3.10.9 or newer installed.

We suggest installing VeloCycle in a separate conda environment, which for example can be created with the command:

```bash
conda create --name velocycle_env python==3.10.9
```

You will probably need to install git next:

```bash
conda install git
```

Then you can install VeloCycle using one of the following two approaches:

1. Install the latest release on PyPI:

```bash
pip install velocycle
```

2. Install the latest development version:

```bash
pip install git+https://github.com/lamanno-epfl/velocycle.git@main
```

## Release notes

This is the initial release of VeloCycle corresponding to an upcoming preprint. These software are still under continuous development.

## Contact

For questions and help requests, you can reach out to [Alex Lederer](mailto:alex.lederer@epfl.ch) and [Gioele La Manno](mailto:gioele.lamanno@epfl.ch). We are happy to hear your feedback and comments!
If you found a bug, please use the [issue tracker](https://github.com/lamanno-epfl/velocycle/issues).

## Additional materials

For notebooks and data files not used in the tutorials included in this repo, but used in the original publication, please see the following [Zenodo]() page and [GEO](), both of which are coming soon!.

## Citation

Coming soon!
